
BASE_URL = 'http://api.summarify.io'
URL = {
        'tokenURL': f'{BASE_URL}/token',
        'sentimentURL': f'{BASE_URL}/sentiment-analysis',
        'nerURL': f'{BASE_URL}/ner',
        'classificationURL': f'{BASE_URL}/classification',
        'zeroshotURL': f'{BASE_URL}/zero-shot',
        'questionURL': f'{BASE_URL}/qa',
        'multirequestURL': f'{BASE_URL}/arguments',
        'summarizationURL': f'{BASE_URL}/summarize',
        'spellCheckURL': f'{BASE_URL}/spell-check'
}
